        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 26 <strong>control</strong><br>0,1,2,4,5,6,12,13,14,15,16,21,22,24,26,31,32,36,37,40,44,45,47,48,49,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 18 <br>8,17,18,19,20,23,25,28,29,30,33,34,35,38,39,41,42,46';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260624 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,7,9,10,11,27,43';}
}
